pub enum SelectorType {
This,
NearestPlayer,
RandomPlayer,
AllPlayers,
AllEntities,
}Variants
Implementations
Sourceimpl SelectorType
impl SelectorType
pub fn codegen_str(&self) -> &'static str
Sourcepub fn is_single_type(&self) -> bool
pub fn is_single_type(&self) -> bool
Checks if this selector type is in single type
Sourcepub fn is_player_type(&self) -> bool
pub fn is_player_type(&self) -> bool
Checks if this selector type is in player type